var classplplot_1_1core_1_1plplotjavac =
[
    [ "pl_setcontlabelformat", "classplplot_1_1core_1_1plplotjavac.html#ab910bd3b84ae68769df6d519cb9936e6", null ],
    [ "pl_setcontlabelparam", "classplplot_1_1core_1_1plplotjavac.html#a61ad3125adfa460cc86b4e52d39c3770", null ],
    [ "pladv", "classplplot_1_1core_1_1plplotjavac.html#a106604b47cac68a53c25ae31a4389cd1", null ],
    [ "plarc", "classplplot_1_1core_1_1plplotjavac.html#af07db6f1643999fd6545e830fed12b6e", null ],
    [ "plaxes", "classplplot_1_1core_1_1plplotjavac.html#a1743288f3a586e71f18985f6bef67d1f", null ],
    [ "plbin", "classplplot_1_1core_1_1plplotjavac.html#a5d2349d9a2863ff7a479e9058d4a6d3b", null ],
    [ "plbop", "classplplot_1_1core_1_1plplotjavac.html#af34744a05f6f8d3b6077ccaf1af69a4a", null ],
    [ "plbox", "classplplot_1_1core_1_1plplotjavac.html#a48a68fc2b2f942f619bb8a01deea5b6c", null ],
    [ "plbox3", "classplplot_1_1core_1_1plplotjavac.html#ae5ac388e27fdfe72643297752ed956ad", null ],
    [ "plbtime", "classplplot_1_1core_1_1plplotjavac.html#a2627b1c17429beab82e4ad947afe7537", null ],
    [ "plcalc_world", "classplplot_1_1core_1_1plplotjavac.html#a2e3c5a0b32f7ce16b9942f6b1413f126", null ],
    [ "plclear", "classplplot_1_1core_1_1plplotjavac.html#afe8a94801082208830096af4c36b2182", null ],
    [ "plClearOpts", "classplplot_1_1core_1_1plplotjavac.html#a716b1895931da40d7602a00ce66d7318", null ],
    [ "plcol0", "classplplot_1_1core_1_1plplotjavac.html#ad29b5794300e79cf3fd0aedc77e22d30", null ],
    [ "plcol1", "classplplot_1_1core_1_1plplotjavac.html#a89734f97fd581ad40d5a1bed97e66202", null ],
    [ "plcolorbar", "classplplot_1_1core_1_1plplotjavac.html#a7bd214a881b6e6baea8a031e91490ad1", null ],
    [ "plconfigtime", "classplplot_1_1core_1_1plplotjavac.html#a8d9b5db78e5122b4a04ca8fb925d800f", null ],
    [ "plcont", "classplplot_1_1core_1_1plplotjavac.html#a28443979015683335460cee5333882f6", null ],
    [ "plcpstrm", "classplplot_1_1core_1_1plplotjavac.html#ae66a738f9996ac29c8c1424e2d63ffc6", null ],
    [ "plctime", "classplplot_1_1core_1_1plplotjavac.html#ae85981b3b4014a1e901b5555d37c3d02", null ],
    [ "plend", "classplplot_1_1core_1_1plplotjavac.html#a2196f8a4f87f004c2c39c5e691bf8884", null ],
    [ "plend1", "classplplot_1_1core_1_1plplotjavac.html#a7ebc2d5c8d526d5406408e17ae7f3680", null ],
    [ "plenv", "classplplot_1_1core_1_1plplotjavac.html#abe487204b2a6ab476f15a6efb6d4050a", null ],
    [ "plenv0", "classplplot_1_1core_1_1plplotjavac.html#aa274c45812113a1f010b857b4080520d", null ],
    [ "pleop", "classplplot_1_1core_1_1plplotjavac.html#a45bcbabaf0b84e3d05b5b9da8a6b6d54", null ],
    [ "plerrx", "classplplot_1_1core_1_1plplotjavac.html#ae1674f8f4e81c267260d076bcbf76f0e", null ],
    [ "plerry", "classplplot_1_1core_1_1plplotjavac.html#aed607aec4ff61458f6697926d7434611", null ],
    [ "plfamadv", "classplplot_1_1core_1_1plplotjavac.html#a24eead295237e248e4f3078c9d8c9bd1", null ],
    [ "plfill", "classplplot_1_1core_1_1plplotjavac.html#a1368f19d0c7c60a9dd3442b9243b79ee", null ],
    [ "plfill3", "classplplot_1_1core_1_1plplotjavac.html#a899cc47d8e0dca23fbfe402a5a8ae622", null ],
    [ "plflush", "classplplot_1_1core_1_1plplotjavac.html#a1c3c13407a47f428a7d3f9783a13d17a", null ],
    [ "plfont", "classplplot_1_1core_1_1plplotjavac.html#a7d9b3d28fcc84d93e8889c61b273752c", null ],
    [ "plfontld", "classplplot_1_1core_1_1plplotjavac.html#a2f40be150916cc809eea0a38290153dc", null ],
    [ "plgchr", "classplplot_1_1core_1_1plplotjavac.html#a3dce5db177fe7913aed8f40b33bdc6e3", null ],
    [ "plgcmap1_range", "classplplot_1_1core_1_1plplotjavac.html#aef51c2ebd7eb538424fd7ab12f0719d6", null ],
    [ "plgcol0", "classplplot_1_1core_1_1plplotjavac.html#abf1387f00b3735ace23b1e2b2769bd23", null ],
    [ "plgcol0a", "classplplot_1_1core_1_1plplotjavac.html#a531a5c26991c158e9e38b79f573f79ab", null ],
    [ "plgcolbg", "classplplot_1_1core_1_1plplotjavac.html#abb927ef002623edb25936aabd11bcee3", null ],
    [ "plgcolbga", "classplplot_1_1core_1_1plplotjavac.html#aef1af8990aa82d19f6d907e4387ff668", null ],
    [ "plgcompression", "classplplot_1_1core_1_1plplotjavac.html#a140849ec9d6ca10aa56bfce0ed8ec8b9", null ],
    [ "plgdev", "classplplot_1_1core_1_1plplotjavac.html#a2b9439976522cd5af86d5369f25b850f", null ],
    [ "plgdidev", "classplplot_1_1core_1_1plplotjavac.html#a8ac516e0c4c02449fde1824d39c54e4e", null ],
    [ "plgdiori", "classplplot_1_1core_1_1plplotjavac.html#a93f10858ece013967e52c9c87d3a2753", null ],
    [ "plgdiplt", "classplplot_1_1core_1_1plplotjavac.html#a0fd43a784203941c2813bd29a5292f7f", null ],
    [ "plGetCursor", "classplplot_1_1core_1_1plplotjavac.html#afb592017c2548d3685e04ce7df1e13aa", null ],
    [ "plgfam", "classplplot_1_1core_1_1plplotjavac.html#a1c895c8f54219d0b33bec8f386122a26", null ],
    [ "plgfci", "classplplot_1_1core_1_1plplotjavac.html#acd063d9ea1afc61f96b71e3b1a0aa47c", null ],
    [ "plgfnam", "classplplot_1_1core_1_1plplotjavac.html#a7a36235e9ef883678ea664e8f8d43249", null ],
    [ "plgfont", "classplplot_1_1core_1_1plplotjavac.html#aca138f4e937ccebf08f236dfb64cc459", null ],
    [ "plglevel", "classplplot_1_1core_1_1plplotjavac.html#a675553a6956b6caffad567e4ab8cc172", null ],
    [ "plgpage", "classplplot_1_1core_1_1plplotjavac.html#a9dea564061ad7ba4d3876d26a3096563", null ],
    [ "plgra", "classplplot_1_1core_1_1plplotjavac.html#a86885c3d850ba4a0bed87cd474923131", null ],
    [ "plgradient", "classplplot_1_1core_1_1plplotjavac.html#a56dd17acf8a9521854ab45cd9650b17e", null ],
    [ "plgriddata", "classplplot_1_1core_1_1plplotjavac.html#a128e15c4e9d6b990fad95da166b84a8d", null ],
    [ "plgspa", "classplplot_1_1core_1_1plplotjavac.html#a85bd4f4426c0cc8eb1fec0d67f7baf27", null ],
    [ "plgstrm", "classplplot_1_1core_1_1plplotjavac.html#aa78da0e7657447bf46c9cb44f7dab3b2", null ],
    [ "plgver", "classplplot_1_1core_1_1plplotjavac.html#afc52e9e267624faade9aabf479318833", null ],
    [ "plgvpd", "classplplot_1_1core_1_1plplotjavac.html#aa6b6ce1ce49927e6f80eb17b170a7aa0", null ],
    [ "plgvpw", "classplplot_1_1core_1_1plplotjavac.html#acee8c1dfbb204f0b7fc525d2115a3ae0", null ],
    [ "plgxax", "classplplot_1_1core_1_1plplotjavac.html#a19d715a81f5423d747d490b9ddf93bc8", null ],
    [ "plgyax", "classplplot_1_1core_1_1plplotjavac.html#ac3d5373f2cc802928d6ecdb7c4c3fe79", null ],
    [ "plgzax", "classplplot_1_1core_1_1plplotjavac.html#a0254e526e8ae7f71a2b5ee766c79a196", null ],
    [ "plhist", "classplplot_1_1core_1_1plplotjavac.html#a89e076b48ad2c389da76b52cb96f714d", null ],
    [ "plhlsrgb", "classplplot_1_1core_1_1plplotjavac.html#a5604642dd4c69c507daa7d9befa41fc4", null ],
    [ "plimage", "classplplot_1_1core_1_1plplotjavac.html#a71c0fdcc5570b5bf1b8cd8de1d920caa", null ],
    [ "plimagefr", "classplplot_1_1core_1_1plplotjavac.html#a4d9533b9ace62ed57d9eb00eb3d78b77", null ],
    [ "plinit", "classplplot_1_1core_1_1plplotjavac.html#ae07745202f68c9d1686de0797c483e0d", null ],
    [ "pljoin", "classplplot_1_1core_1_1plplotjavac.html#aa7f8db2ee6ec71720cfab17fcdf956e5", null ],
    [ "pllab", "classplplot_1_1core_1_1plplotjavac.html#a40042a3de109026519095c8e0c931dce", null ],
    [ "pllegend", "classplplot_1_1core_1_1plplotjavac.html#ae7a46b2d46e0f12ea1a1d7e40e5d2156", null ],
    [ "pllightsource", "classplplot_1_1core_1_1plplotjavac.html#ac411d13e7e0a150b23415cb7e2aa60fe", null ],
    [ "plline", "classplplot_1_1core_1_1plplotjavac.html#ab7dbdfc180f1cad5adb35ab9d92083ca", null ],
    [ "plline3", "classplplot_1_1core_1_1plplotjavac.html#a18e7df412f9a725e50684efa3ccbd5aa", null ],
    [ "pllsty", "classplplot_1_1core_1_1plplotjavac.html#ae17fd662887448e065e219dee2364f3e", null ],
    [ "plmap", "classplplot_1_1core_1_1plplotjavac.html#aa4687f4117e361df48340ad46225801c", null ],
    [ "plmapfill", "classplplot_1_1core_1_1plplotjavac.html#ae47c6fa53755b03fa432a766f2a84966", null ],
    [ "plmapline", "classplplot_1_1core_1_1plplotjavac.html#af6bebf1541e99ff524672adb8b469f18", null ],
    [ "plmapstring", "classplplot_1_1core_1_1plplotjavac.html#ae664bf83af75601d394ef911ce09fc8f", null ],
    [ "plmaptex", "classplplot_1_1core_1_1plplotjavac.html#a247faebeaa76422476d5c92d94d5c0dc", null ],
    [ "plmeridians", "classplplot_1_1core_1_1plplotjavac.html#a816ca5e59bdabea5f6cb37dfb58b8ddf", null ],
    [ "plmesh", "classplplot_1_1core_1_1plplotjavac.html#aa352a17675fc17234aa4d9975c027099", null ],
    [ "plmeshc", "classplplot_1_1core_1_1plplotjavac.html#a376d0f1e234b1ac944c46d51c19f2c88", null ],
    [ "plMinMax2dGrid", "classplplot_1_1core_1_1plplotjavac.html#a3c302321ce0a3e69c7bedfbe556ef178", null ],
    [ "plmkstrm", "classplplot_1_1core_1_1plplotjavac.html#af3982a8e3266b5d93ae7f4367bdb2824", null ],
    [ "plmtex", "classplplot_1_1core_1_1plplotjavac.html#ad1160cd64cb2a2d4b3222e4604adc0c6", null ],
    [ "plmtex3", "classplplot_1_1core_1_1plplotjavac.html#ab1323ae570acacfc11308079563c3b54", null ],
    [ "plOptUsage", "classplplot_1_1core_1_1plplotjavac.html#a00c1736021309ce752d54caedf8198de", null ],
    [ "plot3d", "classplplot_1_1core_1_1plplotjavac.html#ab9cbea9c0c850773111269d07a5b1c75", null ],
    [ "plot3dc", "classplplot_1_1core_1_1plplotjavac.html#ad1461f6e96d692167a7060e557a6eaef", null ],
    [ "plot3dcl", "classplplot_1_1core_1_1plplotjavac.html#a3c6aa3534174bdff78808d964855503a", null ],
    [ "plparseopts", "classplplot_1_1core_1_1plplotjavac.html#aba7b5d6395fb573c7acc36c23165ebd1", null ],
    [ "plpat", "classplplot_1_1core_1_1plplotjavac.html#aef4ffef189da8fa3f10e0fa1543d5269", null ],
    [ "plpath", "classplplot_1_1core_1_1plplotjavac.html#ae1e77c782aef715db248382320464d90", null ],
    [ "plpoin", "classplplot_1_1core_1_1plplotjavac.html#ade05d9592bcf149a877eef47a37ae322", null ],
    [ "plpoin3", "classplplot_1_1core_1_1plplotjavac.html#a1a944af9d9878b631191ee5aefa0e595", null ],
    [ "plpoly3", "classplplot_1_1core_1_1plplotjavac.html#a832d60ac61de0fd3491a733c31dbb03f", null ],
    [ "plprec", "classplplot_1_1core_1_1plplotjavac.html#a9d1115716cd8762aa76487fa6eb06dde", null ],
    [ "plpsty", "classplplot_1_1core_1_1plplotjavac.html#a98924d47d01aca49853e36cff601b92e", null ],
    [ "plptex", "classplplot_1_1core_1_1plplotjavac.html#aef5cb0343739b88d8e7c5f9f4c0a4638", null ],
    [ "plptex3", "classplplot_1_1core_1_1plplotjavac.html#a553db1674dc41ff8c9680427f2fedb1b", null ],
    [ "plrandd", "classplplot_1_1core_1_1plplotjavac.html#afab68da89e808f9e18be92c1d0d670d1", null ],
    [ "plreplot", "classplplot_1_1core_1_1plplotjavac.html#afeadb5980b501e8d83fa1c3733ceaabd", null ],
    [ "plResetOpts", "classplplot_1_1core_1_1plplotjavac.html#a3bcd390dc4cbaf341491e70d41624ebf", null ],
    [ "plrgbhls", "classplplot_1_1core_1_1plplotjavac.html#ad74f9cdca18c5bb2e45da4eb39b3a171", null ],
    [ "plschr", "classplplot_1_1core_1_1plplotjavac.html#a6f12f6c70f6228274451326fc3648889", null ],
    [ "plscmap0", "classplplot_1_1core_1_1plplotjavac.html#aec16e78e9b5f5840538f1bd98d91c638", null ],
    [ "plscmap0a", "classplplot_1_1core_1_1plplotjavac.html#ab8cc9d9393b04838895b3cbc4b244700", null ],
    [ "plscmap0n", "classplplot_1_1core_1_1plplotjavac.html#abb1d2ebc9ccb4dd5786103210078849b", null ],
    [ "plscmap1", "classplplot_1_1core_1_1plplotjavac.html#ab00d150256711d01cfe794de71da58c9", null ],
    [ "plscmap1_range", "classplplot_1_1core_1_1plplotjavac.html#afcc9332440c3a5ecba4f0063be8dc1c9", null ],
    [ "plscmap1a", "classplplot_1_1core_1_1plplotjavac.html#aedae368905f9a8c8a62e78ad61e1783e", null ],
    [ "plscmap1l", "classplplot_1_1core_1_1plplotjavac.html#a723db0222d40ae14da0118b06479bb48", null ],
    [ "plscmap1la", "classplplot_1_1core_1_1plplotjavac.html#a7d833c8532b94bfe4ced92743ee0d18c", null ],
    [ "plscmap1n", "classplplot_1_1core_1_1plplotjavac.html#ac4d495e4125ad582e67ab137f1b53513", null ],
    [ "plscol0", "classplplot_1_1core_1_1plplotjavac.html#a9dd633dd54c5641f27097dc704f1c35f", null ],
    [ "plscol0a", "classplplot_1_1core_1_1plplotjavac.html#a1e8af31634227d3603d1679bf37ebd27", null ],
    [ "plscolbg", "classplplot_1_1core_1_1plplotjavac.html#ae289fe866fa107240f54fd02fab49237", null ],
    [ "plscolbga", "classplplot_1_1core_1_1plplotjavac.html#a63bf26592171d1f7bf892c5f41266c18", null ],
    [ "plscolor", "classplplot_1_1core_1_1plplotjavac.html#a21e9fa4c7e6ed095a2e552b16124d009", null ],
    [ "plscompression", "classplplot_1_1core_1_1plplotjavac.html#a91753b2e8e8e81ac5a5e96a0e0d2e166", null ],
    [ "plsdev", "classplplot_1_1core_1_1plplotjavac.html#afc0749857621c0d56a98801f5b201e9b", null ],
    [ "plsdidev", "classplplot_1_1core_1_1plplotjavac.html#a81584f1456ee856ae8be23c816650837", null ],
    [ "plsdimap", "classplplot_1_1core_1_1plplotjavac.html#aed7f9eb934bece471d1ecfaea815993d", null ],
    [ "plsdiori", "classplplot_1_1core_1_1plplotjavac.html#a923ccbb8ea133e331df4cebc09e8b6b3", null ],
    [ "plsdiplt", "classplplot_1_1core_1_1plplotjavac.html#aa18802a7a5fc5fd2758a4e756bc29bac", null ],
    [ "plsdiplz", "classplplot_1_1core_1_1plplotjavac.html#aa9ac9e6ed982fc58806fe99337785bc2", null ],
    [ "plseed", "classplplot_1_1core_1_1plplotjavac.html#af3ed5015b2a9848f33042c54d48fcaec", null ],
    [ "plsesc", "classplplot_1_1core_1_1plplotjavac.html#a24bf73dd3af6277607d268154b650838", null ],
    [ "plsetopt", "classplplot_1_1core_1_1plplotjavac.html#afb7ec3c8266b1b4af7ee36e79fe97020", null ],
    [ "plSetUsage", "classplplot_1_1core_1_1plplotjavac.html#a062f957a66d2a02c55cc3a0968ad10c3", null ],
    [ "plsfam", "classplplot_1_1core_1_1plplotjavac.html#a9705d2075738bb089452a680982d72f2", null ],
    [ "plsfci", "classplplot_1_1core_1_1plplotjavac.html#a04aca84baec75fd65676accd263ddb88", null ],
    [ "plsfnam", "classplplot_1_1core_1_1plplotjavac.html#a677db5ecda953e3c0bdf6e26c2625096", null ],
    [ "plsfont", "classplplot_1_1core_1_1plplotjavac.html#a901fa39d749a78fffd7167a4f6f1e251", null ],
    [ "plshade", "classplplot_1_1core_1_1plplotjavac.html#a6baa2643cd2c01ec3959c13e08127982", null ],
    [ "plshades", "classplplot_1_1core_1_1plplotjavac.html#abcbd2f5aa371d18f378779a929f22a02", null ],
    [ "plslabelfunc", "classplplot_1_1core_1_1plplotjavac.html#a6ab4119ab605b915760ab25a6e6ea171", null ],
    [ "plsmaj", "classplplot_1_1core_1_1plplotjavac.html#acc9235f44de47ae3833c476c495967e3", null ],
    [ "plsmin", "classplplot_1_1core_1_1plplotjavac.html#ae70aedcaccfd5a8732910cdba8928a4a", null ],
    [ "plsori", "classplplot_1_1core_1_1plplotjavac.html#a82d6ed6e95494d1460711395acfb57cf", null ],
    [ "plspage", "classplplot_1_1core_1_1plplotjavac.html#a8055904eed8fc71d18592ecf5b2c13e9", null ],
    [ "plspal0", "classplplot_1_1core_1_1plplotjavac.html#ae9205cc2766c9b27ca73d31e0581480b", null ],
    [ "plspal1", "classplplot_1_1core_1_1plplotjavac.html#a76e21326354e2e8a00c6ce7b9fc1ff53", null ],
    [ "plspause", "classplplot_1_1core_1_1plplotjavac.html#a22a901482b6103097390ef3dc38951aa", null ],
    [ "plsstrm", "classplplot_1_1core_1_1plplotjavac.html#a026d9523b1ff4ff436a87646241fbaec", null ],
    [ "plssub", "classplplot_1_1core_1_1plplotjavac.html#a790216db6acb7f306e1edb1e248766fb", null ],
    [ "plssym", "classplplot_1_1core_1_1plplotjavac.html#a39d1fbfb04ae453aeac56740209e0bbf", null ],
    [ "plstar", "classplplot_1_1core_1_1plplotjavac.html#a99418153d42626b3342e4f3caf5f9095", null ],
    [ "plstart", "classplplot_1_1core_1_1plplotjavac.html#a6ce180a8988eef00a60554529cc1168b", null ],
    [ "plstransform", "classplplot_1_1core_1_1plplotjavac.html#ac6bb783c22bab5edbcaea7573b050215", null ],
    [ "plstring", "classplplot_1_1core_1_1plplotjavac.html#aa37a497312a50d87db2f8bfe9b66a0e9", null ],
    [ "plstring3", "classplplot_1_1core_1_1plplotjavac.html#a83b7d46d3e521687d402c3b51e60a5b8", null ],
    [ "plstripa", "classplplot_1_1core_1_1plplotjavac.html#adbef91abbb88a2d0d7994a42955ceced", null ],
    [ "plstripc", "classplplot_1_1core_1_1plplotjavac.html#a7a83734a3cc3db7ad18648a275040033", null ],
    [ "plstripd", "classplplot_1_1core_1_1plplotjavac.html#a97c56c490a39c671881009497e9e63bc", null ],
    [ "plstyl", "classplplot_1_1core_1_1plplotjavac.html#a511adfb4df8e5728237452c2c336abdc", null ],
    [ "plsurf3d", "classplplot_1_1core_1_1plplotjavac.html#a5ddff543813eeba68ef21aeddb82755c", null ],
    [ "plsurf3dl", "classplplot_1_1core_1_1plplotjavac.html#ac89774838256beb1aa50514510195740", null ],
    [ "plsvect", "classplplot_1_1core_1_1plplotjavac.html#a8d4b419af568aac87941ca5c61a4d496", null ],
    [ "plsvpa", "classplplot_1_1core_1_1plplotjavac.html#a521449ee751f2c1da78b98d2a9eb0a3d", null ],
    [ "plsxax", "classplplot_1_1core_1_1plplotjavac.html#a0bea620db5f0d021ded6fd1ef4746f93", null ],
    [ "plsyax", "classplplot_1_1core_1_1plplotjavac.html#a3872249fea6792dac82f99e2067b45a2", null ],
    [ "plsym", "classplplot_1_1core_1_1plplotjavac.html#a34bb7ab5028e3175703ff9fcacff7e5e", null ],
    [ "plszax", "classplplot_1_1core_1_1plplotjavac.html#a2316d89a537ceb158bab43068b316504", null ],
    [ "pltext", "classplplot_1_1core_1_1plplotjavac.html#aa7d14424bfeb8dd1e53e39c433724b50", null ],
    [ "pltimefmt", "classplplot_1_1core_1_1plplotjavac.html#ad1d558573c9e5f69271ca58ce993a6df", null ],
    [ "plvasp", "classplplot_1_1core_1_1plplotjavac.html#a4d5d995c56ad9e9f07ea3cb098c1e1ad", null ],
    [ "plvect", "classplplot_1_1core_1_1plplotjavac.html#a78895e4925002a4f4b3efd9dc030cd42", null ],
    [ "plvpas", "classplplot_1_1core_1_1plplotjavac.html#a0bf89f550b56fb115683d14d77c82d04", null ],
    [ "plvpor", "classplplot_1_1core_1_1plplotjavac.html#af9f58e19b12874eb0545bb04658c1556", null ],
    [ "plvsta", "classplplot_1_1core_1_1plplotjavac.html#a2b7967478f182ce1c420445561fc6c78", null ],
    [ "plw3d", "classplplot_1_1core_1_1plplotjavac.html#ad2a04faea2371864eca40b85711367b5", null ],
    [ "plwidth", "classplplot_1_1core_1_1plplotjavac.html#adb3bab18ff8e5c5d73db1cc3dd661d9e", null ],
    [ "plwind", "classplplot_1_1core_1_1plplotjavac.html#a99a19baca13a1998142ee0081e6c7282", null ],
    [ "plxormod", "classplplot_1_1core_1_1plplotjavac.html#a620fa8b9a963e5797d55c966df1912fb", null ]
];